package michael.msn.jml;

import java.util.Scanner;

import net.sf.jml.MsnContact;
import net.sf.jml.MsnMessenger;
import net.sf.jml.MsnProtocol;
import net.sf.jml.MsnUserStatus;
import net.sf.jml.impl.MsnMessengerFactory;

import org.apache.log4j.PropertyConfigurator;

/**
 * @author michael
 * 
 */
public class MyJmsnClient {
    private String msnEmail;

    private String msnPassword;

    private MsnMessenger msn;

    /**
     * @param msnEmail
     * @param msnPassword
     */
    public MyJmsnClient(String msnEmail, String msnPassword) {
        this.msnEmail = msnEmail;
        this.msnPassword = msnPassword;
    }

    /**
     * 启动
     */
    public void start() {
        // 创建MsnMessenger
        msn = MsnMessengerFactory.createMsnMessenger(msnEmail, msnPassword);
        // 设置登录协议 MSNP15 可以发送离线消息
        msn.setSupportedProtocol(new MsnProtocol[] { MsnProtocol.MSNP15 });
        // 设置用户状态
        msn.getOwner().setInitStatus(MsnUserStatus.ONLINE);
        // 注册事件监听
        msn.addListener(new MyJmsnSimpleAdapter());
        msn.login();// 登录
    }

    /**
     * msn logout
     */
    public void stop() {
        msn.logout();
    }

    /**
     * 给所有的人发消息
     * @param msg
     */
    public void sendAllMsg(String msg) {
        MsnContact[] contactList = msn.getContactList().getContacts();
        for (MsnContact con : contactList) {
            msn.sendText(con.getEmail(), msg);
        }
    }

    /**
     * @param args
     */
    public static void main(String[] args) {
        PropertyConfigurator.configure(MyJmsnClient.class
                .getResource("/log4j.properties"));
        MyJmsnClient client = new MyJmsnClient("xxxx", "xxx");
        System.out.println(" MyJmsnClient start ...");
        client.start();
        try {
            Thread.sleep(5000);
        } catch (Exception e) {
            e.printStackTrace();
        }

        //获取控制台输入的信息发送给所有的好友
        Scanner input = new Scanner(System.in);
        while (input.hasNext()) {
            String s = input.next();
            if ("quit".equals(s)) {
                System.out.println(" MSN exit by quit");
                client.stop();
                break;
            } else {
                client.sendAllMsg(s);
            }
        }
        System.out.println("=====================");
    }
}
